@@ -3,7 +3,6 @@ import logging
 import markdown
 from markdown.extensions.tables import TableExtension
 from markdown_blockdiag import BlockdiagExtension
-
 from rest_framework.renderers import StaticHTMLRenderer
 from rest_framework.decorators import action, renderer_classes
 
@@ -38,9 +37,11 @@ class InstanceMixin:
         serialized_content = {"instance": serializer.data}
 
         if hasattr(self, "get_messages"):
-            serialized_content["messages"] = self.get_messages(
+            messages = self.get_messages(
                 request=request, instance=instance
             )
+            if messages:
+                serialized_content["messages"] = [dict(message) for message in messages]
 
         return Response(serialized_content)
 
